==> geary_3.38.1.orig.tar.xz: geary-3.38.1/README.md <==

Geary: Send and receive email
=============================

![Geary icon](https://wiki.gnome.org/Apps/Geary?action=AttachFile&do=get&target=geary-3-32-256-logo.png)

Geary is an email application built around conversations, for the
GNOME 3 desktop. It allows you to read, find and send email with a
straightforward, modern interface.

Visit https://wiki.gnome.org/Apps/Geary for more information.

**GitHub users please note**: Bug reports, code contributions and
translations are managed using GNOME's infrastructure, so we cannot
accept tickets or pull requests on GitHub. Please see the links below
for more information.

![Geary displaying a conversation](https://wiki.gnome.org/Apps/Geary?action=AttachFile&amp;do=get&amp;target=geary-3-32-main-window.png)

Installation & Licensing
------------------------

Please consult the [INSTALL](./INSTALL) and [COPYING](./COPYING) files
for more information.

Getting in Touch
----------------

 * Geary wiki: https://wiki.gnome.org/Apps/Geary
 * Support and discussion: See the `geary` tag on [GNOME Discourse](https://discourse.gnome.org/tags/c/applications/7/geary)
 * Matrix channel: [#geary:gnome.org](https://gnome.element.io/#/room/#geary:gnome.org)

**Code Of Conduct**

We follow the [Contributor Covenant](./code-of-conduct.md) as our
Code of Conduct. All communications in project spaces are expected to
adhere to it.

Contributing to Geary
---------------------

Want to help improve Geary? Here are some ways to contribute:

 * Bug reporting: https://wiki.gnome.org/Apps/Geary/ReportingABug
 * Translating:   https://wiki.gnome.org/Apps/Geary/Translating
 * Development:   https://wiki.gnome.org/Apps/Geary/Development
 * Donate:        https://wiki.gnome.org/Apps/Geary/Donate

---
Copyright 2016 Software Freedom Conservancy Inc.  
Copyright 2017-2020 Michael Gratton <mike@vee.net>

==> geary_43.0.orig.tar.xz: geary-43.0/README.md <==

Geary: Send and receive email
=============================

![Geary icon](https://wiki.gnome.org/Apps/Geary?action=AttachFile&do=get&target=geary-3-32-256-logo.png)

Geary is an email application built around conversations, for the
GNOME 3 desktop. It allows you to read, find and send email with a
straight-forward, modern interface.

Visit https://wiki.gnome.org/Apps/Geary for more information.

**GitHub users please note**: Bug reports, code contributions and
translations are managed using GNOME's infrastructure, so we cannot
accept tickets or pull requests on GitHub. Please see the links below
for more information.

![Geary displaying a conversation](https://wiki.gnome.org/Apps/Geary?action=AttachFile&amp;do=get&amp;target=geary-3-32-main-window.png)

Building & Licensing
--------------------

Please consult the [BUILDING.md](./BUILDING.md) and
[COPYING](./COPYING) files for more information about building Geary
and the licence granted by its copyright holders for redistribution.

Getting in Touch
----------------

 * Geary wiki: https://wiki.gnome.org/Apps/Geary
 * Support and discussion: See the `geary` tag on [GNOME Discourse](https://discourse.gnome.org/tags/c/applications/7/geary)
 * Matrix channel: [#geary:gnome.org](https://gnome.element.io/#/room/#geary:gnome.org)

Code Of Conduct
---------------

We follow the [Contributor Covenant](./code-of-conduct.md) as our
Code of Conduct. All communications in project spaces are expected to
adhere to it.

Contributing to Geary
---------------------

Want to help improve Geary? Here are some ways to contribute:

 * Bug reporting: https://wiki.gnome.org/Apps/Geary/ReportingABug
 * Translating:   https://wiki.gnome.org/Apps/Geary/Translating
 * Development:   https://wiki.gnome.org/Apps/Geary/Development
 * Donate:        https://wiki.gnome.org/Apps/Geary/Donate

---
Copyright © 2016 Software Freedom Conservancy Inc.  
Copyright © 2017-2020 Michael Gratton <mike@vee.net>
